ConnectionConfig

Struct ConnectionConfig 

pub struct ConnectionConfig {
Show 15 fields pub port: Option<u16>, pub timeout: Option<Duration>, pub min_dialect: Option<Dialect>, pub max_dialect: Option<Dialect>, pub encryption_mode: EncryptionMode, pub allow_unsigned_guest_access: bool, pub compression_enabled: bool, pub multichannel: MultiChannelConfig, pub client_name: Option<String>, pub disable_notifications: bool, pub smb2_only_negotiate: bool, pub transport: TransportConfig, pub auth_methods: AuthMethodsConfig, pub credits_backlog: Option<u16>, pub default_transaction_size: Option<u32>,
}
Specifies the configuration for a connection.

Fields

port: Option<u16>

Specifies the server port to connect to. If unset, defaults to the default port for the selected transport protocol.

timeout: Option<Duration>

Specifies the timeout for the connection. If unset, defaults to ConnectionConfig::DEFAULT_TIMEOUT. 0 means wait forever. Access the timeout using the ConnectionConfig::timeout() method.

min_dialect: Option<Dialect>

Specifies the minimum and maximum dialects to be used in the connection.

Note, that if set, the minimum dialect must be less than or equal to the maximum dialect.

max_dialect: Option<Dialect>

Specifies the minimum and maximum dialects to be used in the connection.

Note, that if set, the minimum dialect must be less than or equal to the maximum dialect.

encryption_mode: EncryptionMode

Sets the encryption mode for the connection. See EncryptionMode for more information.

allow_unsigned_guest_access: bool

Sets whether signing may be skipped for guest or anonymous access.

compression_enabled: bool

Whether to enable compression, if supported by the server and specified connection dialects.

Note: you must also have compression features enabled when building the crate, otherwise compression would not be available. The compression feature is enabled by default.

multichannel: MultiChannelConfig

Multi-channel configuration

client_name: Option<String>

Specifies the client host name to be used in the SMB2 negotiation & session setup.

disable_notifications: bool

Specifies whether to disable support for Server-to-client notifications. If set to true, the client will NOT support notifications.

smb2_only_negotiate: bool

Whether to avoid multi-protocol negotiation, and perform smb2-only negotiation. This results in a faster negotiation process, but it might fail with some servers,

transport: TransportConfig

Specifies the transport protocol to be used for the connection.

auth_methods: AuthMethodsConfig

Configures valid authentication methods (SSPs) for the connection. See AuthMethodsConfig for more information.

credits_backlog: Option<u16>

The number of SMB2 credits to request for the connection. If not configured, uses a default value.

The higher number of credits, the more concurrent requests can be sent on the connection. However, some servers may not issue such high number of credits.

This is the somewhat similar to the -Smb2MaxCredits parameter in the Set-SmbServerConfiguration PowerShell cmdlet, but from the client’s side.

default_transaction_size: Option<u32>

The default size, in bytes, of the buffer that can be used for ResourceHandle::query_info, ResourceHandle::query_fs_info, ResourceHandle::query_security_info, Directory::query_quota_info, their respective set_*_info counterparts (such as ResourceHandle::set_info), Directory::query and Directory::watch operations.

Implementations

Source

impl ConnectionConfig

pub const DEFAULT_TIMEOUT: Duration

pub const DEFAULT_TRANSACTION_SIZE: u32 = 65_536u32

pub fn validate(&self) -> Result<()>

Validates common configuration settings.

pub fn timeout(&self) -> Duration

Returns the effective timeout to be used if timeout is not set.

pub fn default_transaction_size(&self) -> u32

Returns the effective value to be used if default_transaction_size is not set.