pub struct TransformError {
pub outgoing: bool,
pub phase: TransformPhase,
pub session_id: Option<u64>,
pub why: &'static str,
pub msg_id: Option<u64>,
}Expand description
An error that can occur during the transformation of messages.
Fields
outgoing: boolIf true, the error occurred while transforming an outgoing message. If false, it occurred while transforming an incoming message.
phase: TransformPhasesession_id: Option<u64>why: &'static strmsg_id: Option<u64>If a message ID is available, it will be set here, for error-handling purposes.