pub enum Error {
Show 37 variants
InvalidMessage(String),
IoError(Error),
BinRWError(Error),
ParsingError(TryFromIntError),
ConnectionStopped,
Cancelled(&'static str),
InvalidState(String),
TranformFailed(TransformError),
CryptoError(CryptoError),
NegotiationError(String),
SignatureVerificationFailed,
UnexpectedMessageStatus(u32),
ReceivedErrorMessage(u32, ErrorResponse),
UnexpectedMessageCommand(Command),
MissingPermissions(String),
SspiError(Error),
BufferTooSmall {
data_type: &'static str,
required: Option<usize>,
provided: usize,
},
UrlParseError(ParseError),
UnsupportedAuthenticationMechanism(String),
CompressionError(CompressionError),
MessageProcessingError(String),
OperationTimeout(TimedOutTask, Duration),
LockError,
JoinError(JoinError),
AcquireError(AcquireError),
UnexpectedMessageId(u64, u64),
InvalidConfiguration(String),
InvalidArgument(String),
UnsupportedOperation(String),
DfsError(UncPath),
NotFound(String),
ChannelNotFound(u64, u32),
RpcError(SmbRpcError),
SmbMessageError(SmbMsgError),
FsccError(SmbFsccError),
TransportError(TransportError),
Other(&'static str),
}Variants
InvalidMessage(String)
IoError(Error)
BinRWError(Error)
ParsingError(TryFromIntError)
ConnectionStopped
Indicates connection stopped - due to error or closed by user.
See TransportError::NotConnected for transport-level disconnection.
Usually, this is the actual error returned when trying to use a stopped connection, anyway.
Cancelled(&'static str)
InvalidState(String)
TranformFailed(TransformError)
CryptoError(CryptoError)
NegotiationError(String)
Indicates that the negotiation phase of the SMB protocol failed.
This might be due to incompatible protocol versions, unsupported features, or configuration issues between the client and server.
SignatureVerificationFailed
UnexpectedMessageStatus(u32)
ReceivedErrorMessage(u32, ErrorResponse)
UnexpectedMessageCommand(Command)
MissingPermissions(String)
SspiError(Error)
Indicates an error sourced from the underlying authentication SSPI (Security Support Provider Interface) library.
SSPI is used for handling authentication mechanisms like NTLM and Kerberos.
For more references, see the sspi crate documentation
BufferTooSmall
UrlParseError(ParseError)
UnsupportedAuthenticationMechanism(String)
CompressionError(CompressionError)
MessageProcessingError(String)
OperationTimeout(TimedOutTask, Duration)
LockError
JoinError(JoinError)
AcquireError(AcquireError)
UnexpectedMessageId(u64, u64)
InvalidConfiguration(String)
InvalidArgument(String)
UnsupportedOperation(String)
DfsError(UncPath)
NotFound(String)
ChannelNotFound(u64, u32)
RpcError(SmbRpcError)
SmbMessageError(SmbMsgError)
FsccError(SmbFsccError)
TransportError(TransportError)
Other(&'static str)