pub struct FileCreateArgs {
pub disposition: CreateDisposition,
pub attributes: FileAttributes,
pub options: CreateOptions,
pub desired_access: FileAccessMask,
}Fields
disposition: CreateDispositionattributes: FileAttributesoptions: CreateOptionsdesired_access: FileAccessMaskImplementations
Sourceimpl FileCreateArgs
impl FileCreateArgs
pub fn make_open_existing(access: FileAccessMask) -> FileCreateArgs
Sourcepub fn make_create_new(
attributes: FileAttributes,
options: CreateOptions,
) -> FileCreateArgs
pub fn make_create_new( attributes: FileAttributes, options: CreateOptions, ) -> FileCreateArgs
Returns arguments for creating a new file, with the default access set to Generic All.
Sourcepub fn make_overwrite(
attributes: FileAttributes,
options: CreateOptions,
) -> FileCreateArgs
pub fn make_overwrite( attributes: FileAttributes, options: CreateOptions, ) -> FileCreateArgs
Returns arguments for creating a new file, with the default access set to Generic All. overwrites existing file, if it exists.
Sourcepub fn make_pipe() -> FileCreateArgs
pub fn make_pipe() -> FileCreateArgs
Returns arguments for opening a duplex pipe (rw).