pub struct FileAttributeTagInformation {
pub file_attributes: u32,
pub reparse_tag: u32,
}Fields
file_attributes: u32reparse_tag: u32Trait Implementations
Sourceimpl BinRead for FileAttributeTagInformation
impl BinRead for FileAttributeTagInformation
Sourcefn read_options<R>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: <FileAttributeTagInformation as BinRead>::Args<'_>,
) -> Result<FileAttributeTagInformation, Error>
fn read_options<R>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: <FileAttributeTagInformation as BinRead>::Args<'_>, ) -> Result<FileAttributeTagInformation, Error>
Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments. Read moreSourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader using the given arguments. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for FileAttributeTagInformation
impl BinWrite for FileAttributeTagInformation
Sourcefn write_options<W>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: <FileAttributeTagInformation as BinWrite>::Args<'_>,
) -> Result<(), Error>
fn write_options<W>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: <FileAttributeTagInformation as BinWrite>::Args<'_>, ) -> Result<(), Error>
Sourcefn write<W>(&self, writer: &mut W) -> Result<(), Error>
fn write<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer using default arguments. Read moreSourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer using the given arguments. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Debug for FileAttributeTagInformation
impl Debug for FileAttributeTagInformation
Sourceimpl From<FileAttributeTagInformation> for QueryFileInfo
impl From<FileAttributeTagInformation> for QueryFileInfo
Sourcefn from(value: FileAttributeTagInformation) -> QueryFileInfo
fn from(value: FileAttributeTagInformation) -> QueryFileInfo
Converts to this type from the input type.
Sourceimpl QueryFileInfoValue for FileAttributeTagInformation
impl QueryFileInfoValue for FileAttributeTagInformation
const CLASS_ID: QueryFileInfoClass = QueryFileInfoClass::AttributeTagInformation
Sourceimpl TryFrom<QueryFileInfo> for FileAttributeTagInformation
impl TryFrom<QueryFileInfo> for FileAttributeTagInformation
Sourcetype Error = SmbFsccError
type Error = SmbFsccError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: QueryFileInfo,
) -> Result<FileAttributeTagInformation, <FileAttributeTagInformation as TryFrom<QueryFileInfo>>::Error>
fn try_from( value: QueryFileInfo, ) -> Result<FileAttributeTagInformation, <FileAttributeTagInformation as TryFrom<QueryFileInfo>>::Error>
Performs the conversion.
impl Eq for FileAttributeTagInformation
impl StructuralPartialEq for FileAttributeTagInformation