pub struct FileBothDirectoryInformationInner {Show 13 fields
pub file_index: u32,
pub creation_time: FileTime,
pub last_access_time: FileTime,
pub last_write_time: FileTime,
pub change_time: FileTime,
pub end_of_file: u64,
pub allocation_size: u64,
pub file_attributes: FileAttributes,
pub ea_size: Option<u32>,
pub reparse_tag: Option<ReparseTag>,
pub short_name_length: u8,
pub short_name: [u16; 24],
pub file_name: BaseSizedString<u16>,
}Fields
file_index: u32creation_time: FileTimelast_access_time: FileTimelast_write_time: FileTimechange_time: FileTimeend_of_file: u64allocation_size: u64file_attributes: FileAttributesea_size: Option<u32>reparse_tag: Option<ReparseTag>short_name_length: u8short_name: [u16; 24]file_name: BaseSizedString<u16>Trait Implementations
Sourceimpl BinRead for FileBothDirectoryInformationInner
impl BinRead for FileBothDirectoryInformationInner
Sourcefn read_options<R>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: <FileBothDirectoryInformationInner as BinRead>::Args<'_>,
) -> Result<FileBothDirectoryInformationInner, Error>
fn read_options<R>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: <FileBothDirectoryInformationInner as BinRead>::Args<'_>, ) -> Result<FileBothDirectoryInformationInner, Error>
Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments. Read moreSourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader using the given arguments. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for FileBothDirectoryInformationInner
impl BinWrite for FileBothDirectoryInformationInner
Sourcefn write_options<W>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: <FileBothDirectoryInformationInner as BinWrite>::Args<'_>,
) -> Result<(), Error>
fn write_options<W>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: <FileBothDirectoryInformationInner as BinWrite>::Args<'_>, ) -> Result<(), Error>
Sourcefn write<W>(&self, writer: &mut W) -> Result<(), Error>
fn write<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer using default arguments. Read moreSourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer using the given arguments. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl PartialEq for FileBothDirectoryInformationInner
impl PartialEq for FileBothDirectoryInformationInner
Sourcefn eq(&self, other: &FileBothDirectoryInformationInner) -> bool
fn eq(&self, other: &FileBothDirectoryInformationInner) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for FileBothDirectoryInformationInner
impl StructuralPartialEq for FileBothDirectoryInformationInner