pub struct FileFsAttributeInformation {
pub attributes: FileSystemAttributes,
pub maximum_component_name_length: u32,
pub file_system_name_length: u32,
pub file_system_name: BaseSizedString<u16>,
}Fields
attributes: FileSystemAttributesmaximum_component_name_length: u32file_system_name_length: u32file_system_name: BaseSizedString<u16>Trait Implementations
Sourceimpl BinRead for FileFsAttributeInformation
impl BinRead for FileFsAttributeInformation
Sourcefn read_options<R>(
__binrw_generated_var_reader: &mut R,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: <FileFsAttributeInformation as BinRead>::Args<'_>,
) -> Result<FileFsAttributeInformation, Error>
fn read_options<R>( __binrw_generated_var_reader: &mut R, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: <FileFsAttributeInformation as BinRead>::Args<'_>, ) -> Result<FileFsAttributeInformation, Error>
Sourcefn read<R>(reader: &mut R) -> Result<Self, Error>
fn read<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments. Read moreSourcefn read_be<R>(reader: &mut R) -> Result<Self, Error>
fn read_be<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
big-endian byte order. Read moreSourcefn read_le<R>(reader: &mut R) -> Result<Self, Error>
fn read_le<R>(reader: &mut R) -> Result<Self, Error>
Read
Self from the reader using default arguments and assuming
little-endian byte order. Read moreSourcefn read_ne<R>(reader: &mut R) -> Result<Self, Error>
fn read_ne<R>(reader: &mut R) -> Result<Self, Error>
Read
T from the reader assuming native-endian byte order. Read moreSourcefn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader using the given arguments. Read moreSourcefn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
fn read_be_args<R>(reader: &mut R, args: Self::Args<'_>) -> Result<Self, Error>
Read
Self from the reader, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl BinWrite for FileFsAttributeInformation
impl BinWrite for FileFsAttributeInformation
Sourcefn write_options<W>(
&self,
__binrw_generated_var_writer: &mut W,
__binrw_generated_var_endian: Endian,
__binrw_generated_var_arguments: <FileFsAttributeInformation as BinWrite>::Args<'_>,
) -> Result<(), Error>
fn write_options<W>( &self, __binrw_generated_var_writer: &mut W, __binrw_generated_var_endian: Endian, __binrw_generated_var_arguments: <FileFsAttributeInformation as BinWrite>::Args<'_>, ) -> Result<(), Error>
Sourcefn write<W>(&self, writer: &mut W) -> Result<(), Error>
fn write<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer using default arguments. Read moreSourcefn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_be<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming big-endian byte order. Read moreSourcefn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_le<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming little-endian byte order. Read moreSourcefn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
fn write_ne<W>(&self, writer: &mut W) -> Result<(), Error>
Write
Self to the writer assuming native-endian byte order. Read moreSourcefn write_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer using the given arguments. Read moreSourcefn write_be_args<W>(
&self,
writer: &mut W,
args: Self::Args<'_>,
) -> Result<(), Error>
fn write_be_args<W>( &self, writer: &mut W, args: Self::Args<'_>, ) -> Result<(), Error>
Write
Self to the writer, assuming big-endian byte order, using the
given arguments. Read moreSourceimpl Debug for FileFsAttributeInformation
impl Debug for FileFsAttributeInformation
Sourceimpl From<FileFsAttributeInformation> for QueryFileSystemInfo
impl From<FileFsAttributeInformation> for QueryFileSystemInfo
Sourcefn from(value: FileFsAttributeInformation) -> QueryFileSystemInfo
fn from(value: FileFsAttributeInformation) -> QueryFileSystemInfo
Converts to this type from the input type.
Sourceimpl QueryFileSystemInfoValue for FileFsAttributeInformation
impl QueryFileSystemInfoValue for FileFsAttributeInformation
const CLASS_ID: QueryFileSystemInfoClass = QueryFileSystemInfoClass::FsAttributeInformation
Sourceimpl TryFrom<QueryFileSystemInfo> for FileFsAttributeInformation
impl TryFrom<QueryFileSystemInfo> for FileFsAttributeInformation
Sourcetype Error = SmbFsccError
type Error = SmbFsccError
The type returned in the event of a conversion error.
Sourcefn try_from(
value: QueryFileSystemInfo,
) -> Result<FileFsAttributeInformation, <FileFsAttributeInformation as TryFrom<QueryFileSystemInfo>>::Error>
fn try_from( value: QueryFileSystemInfo, ) -> Result<FileFsAttributeInformation, <FileFsAttributeInformation as TryFrom<QueryFileSystemInfo>>::Error>
Performs the conversion.
impl Eq for FileFsAttributeInformation
impl StructuralPartialEq for FileFsAttributeInformation