MandatoryLabelAccessMask

Struct MandatoryLabelAccessMask 

pub struct MandatoryLabelAccessMask { /* private fields */ }

Implementations

Source

impl MandatoryLabelAccessMask

pub const fn new() -> MandatoryLabelAccessMask

Returns an instance with zero initialized data.

Source

impl MandatoryLabelAccessMask

pub const fn into_bytes(self) -> [u8; 4]

Returns the underlying bits.

Layout

The returned byte array is layed out in the same way as described here.

pub const fn from_bytes(bytes: [u8; 4]) -> MandatoryLabelAccessMask

Converts the given bytes directly into the bitfield struct.

Source

impl MandatoryLabelAccessMask

pub fn no_write_up(&self) -> <bool as Specifier>::InOut

Returns the value of no_write_up.

pub fn no_write_up_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of no_write_up.

#Errors

If the returned value contains an invalid bit pattern for no_write_up.

pub fn with_no_write_up( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of no_write_up set to the given value.

#Panics

If the given value is out of bounds for no_write_up.

pub fn with_no_write_up_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of no_write_up set to the given value.

#Errors

If the given value is out of bounds for no_write_up.

pub fn set_no_write_up(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of no_write_up to the given value.

#Panics

If the given value is out of bounds for no_write_up.

pub fn set_no_write_up_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of no_write_up to the given value.

#Errors

If the given value is out of bounds for no_write_up.

pub fn no_read_up(&self) -> <bool as Specifier>::InOut

Returns the value of no_read_up.

pub fn no_read_up_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of no_read_up.

#Errors

If the returned value contains an invalid bit pattern for no_read_up.

pub fn with_no_read_up( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of no_read_up set to the given value.

#Panics

If the given value is out of bounds for no_read_up.

pub fn with_no_read_up_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of no_read_up set to the given value.

#Errors

If the given value is out of bounds for no_read_up.

pub fn set_no_read_up(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of no_read_up to the given value.

#Panics

If the given value is out of bounds for no_read_up.

pub fn set_no_read_up_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of no_read_up to the given value.

#Errors

If the given value is out of bounds for no_read_up.

pub fn no_execute_up(&self) -> <bool as Specifier>::InOut

Returns the value of no_execute_up.

pub fn no_execute_up_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of no_execute_up.

#Errors

If the returned value contains an invalid bit pattern for no_execute_up.

pub fn with_no_execute_up( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of no_execute_up set to the given value.

#Panics

If the given value is out of bounds for no_execute_up.

pub fn with_no_execute_up_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of no_execute_up set to the given value.

#Errors

If the given value is out of bounds for no_execute_up.

pub fn set_no_execute_up(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of no_execute_up to the given value.

#Panics

If the given value is out of bounds for no_execute_up.

pub fn set_no_execute_up_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of no_execute_up to the given value.

#Errors

If the given value is out of bounds for no_execute_up.

pub fn delete(&self) -> <bool as Specifier>::InOut

Returns the value of delete.

pub fn delete_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of delete.

#Errors

If the returned value contains an invalid bit pattern for delete.

pub fn with_delete( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of delete set to the given value.

#Panics

If the given value is out of bounds for delete.

pub fn with_delete_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of delete set to the given value.

#Errors

If the given value is out of bounds for delete.

pub fn set_delete(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of delete to the given value.

#Panics

If the given value is out of bounds for delete.

pub fn set_delete_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of delete to the given value.

#Errors

If the given value is out of bounds for delete.

pub fn read_control(&self) -> <bool as Specifier>::InOut

Returns the value of read_control.

pub fn read_control_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of read_control.

#Errors

If the returned value contains an invalid bit pattern for read_control.

pub fn with_read_control( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of read_control set to the given value.

#Panics

If the given value is out of bounds for read_control.

pub fn with_read_control_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of read_control set to the given value.

#Errors

If the given value is out of bounds for read_control.

pub fn set_read_control(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of read_control to the given value.

#Panics

If the given value is out of bounds for read_control.

pub fn set_read_control_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of read_control to the given value.

#Errors

If the given value is out of bounds for read_control.

pub fn write_dacl(&self) -> <bool as Specifier>::InOut

Returns the value of write_dacl.

pub fn write_dacl_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of write_dacl.

#Errors

If the returned value contains an invalid bit pattern for write_dacl.

pub fn with_write_dacl( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of write_dacl set to the given value.

#Panics

If the given value is out of bounds for write_dacl.

pub fn with_write_dacl_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of write_dacl set to the given value.

#Errors

If the given value is out of bounds for write_dacl.

pub fn set_write_dacl(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of write_dacl to the given value.

#Panics

If the given value is out of bounds for write_dacl.

pub fn set_write_dacl_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of write_dacl to the given value.

#Errors

If the given value is out of bounds for write_dacl.

pub fn write_owner(&self) -> <bool as Specifier>::InOut

Returns the value of write_owner.

pub fn write_owner_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of write_owner.

#Errors

If the returned value contains an invalid bit pattern for write_owner.

pub fn with_write_owner( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of write_owner set to the given value.

#Panics

If the given value is out of bounds for write_owner.

pub fn with_write_owner_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of write_owner set to the given value.

#Errors

If the given value is out of bounds for write_owner.

pub fn set_write_owner(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of write_owner to the given value.

#Panics

If the given value is out of bounds for write_owner.

pub fn set_write_owner_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of write_owner to the given value.

#Errors

If the given value is out of bounds for write_owner.

pub fn synchronize(&self) -> <bool as Specifier>::InOut

Returns the value of synchronize.

pub fn synchronize_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of synchronize.

#Errors

If the returned value contains an invalid bit pattern for synchronize.

pub fn with_synchronize( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of synchronize set to the given value.

#Panics

If the given value is out of bounds for synchronize.

pub fn with_synchronize_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of synchronize set to the given value.

#Errors

If the given value is out of bounds for synchronize.

pub fn set_synchronize(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of synchronize to the given value.

#Panics

If the given value is out of bounds for synchronize.

pub fn set_synchronize_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of synchronize to the given value.

#Errors

If the given value is out of bounds for synchronize.

pub fn access_system_security(&self) -> <bool as Specifier>::InOut

Returns the value of access_system_security.

pub fn access_system_security_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of access_system_security.

#Errors

If the returned value contains an invalid bit pattern for access_system_security.

pub fn with_access_system_security( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of access_system_security set to the given value.

#Panics

If the given value is out of bounds for access_system_security.

pub fn with_access_system_security_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of access_system_security set to the given value.

#Errors

If the given value is out of bounds for access_system_security.

pub fn set_access_system_security( &mut self, new_val: <bool as Specifier>::InOut, )

Sets the value of access_system_security to the given value.

#Panics

If the given value is out of bounds for access_system_security.

pub fn set_access_system_security_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of access_system_security to the given value.

#Errors

If the given value is out of bounds for access_system_security.

pub fn maximum_allowed(&self) -> <bool as Specifier>::InOut

Returns the value of maximum_allowed.

pub fn maximum_allowed_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of maximum_allowed.

#Errors

If the returned value contains an invalid bit pattern for maximum_allowed.

pub fn with_maximum_allowed( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of maximum_allowed set to the given value.

#Panics

If the given value is out of bounds for maximum_allowed.

pub fn with_maximum_allowed_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of maximum_allowed set to the given value.

#Errors

If the given value is out of bounds for maximum_allowed.

pub fn set_maximum_allowed(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of maximum_allowed to the given value.

#Panics

If the given value is out of bounds for maximum_allowed.

pub fn set_maximum_allowed_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of maximum_allowed to the given value.

#Errors

If the given value is out of bounds for maximum_allowed.

pub fn generic_all(&self) -> <bool as Specifier>::InOut

Returns the value of generic_all.

pub fn generic_all_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of generic_all.

#Errors

If the returned value contains an invalid bit pattern for generic_all.

pub fn with_generic_all( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of generic_all set to the given value.

#Panics

If the given value is out of bounds for generic_all.

pub fn with_generic_all_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of generic_all set to the given value.

#Errors

If the given value is out of bounds for generic_all.

pub fn set_generic_all(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of generic_all to the given value.

#Panics

If the given value is out of bounds for generic_all.

pub fn set_generic_all_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of generic_all to the given value.

#Errors

If the given value is out of bounds for generic_all.

pub fn generic_execute(&self) -> <bool as Specifier>::InOut

Returns the value of generic_execute.

pub fn generic_execute_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of generic_execute.

#Errors

If the returned value contains an invalid bit pattern for generic_execute.

pub fn with_generic_execute( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of generic_execute set to the given value.

#Panics

If the given value is out of bounds for generic_execute.

pub fn with_generic_execute_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of generic_execute set to the given value.

#Errors

If the given value is out of bounds for generic_execute.

pub fn set_generic_execute(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of generic_execute to the given value.

#Panics

If the given value is out of bounds for generic_execute.

pub fn set_generic_execute_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of generic_execute to the given value.

#Errors

If the given value is out of bounds for generic_execute.

pub fn generic_write(&self) -> <bool as Specifier>::InOut

Returns the value of generic_write.

pub fn generic_write_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of generic_write.

#Errors

If the returned value contains an invalid bit pattern for generic_write.

pub fn with_generic_write( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of generic_write set to the given value.

#Panics

If the given value is out of bounds for generic_write.

pub fn with_generic_write_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of generic_write set to the given value.

#Errors

If the given value is out of bounds for generic_write.

pub fn set_generic_write(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of generic_write to the given value.

#Panics

If the given value is out of bounds for generic_write.

pub fn set_generic_write_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of generic_write to the given value.

#Errors

If the given value is out of bounds for generic_write.

pub fn generic_read(&self) -> <bool as Specifier>::InOut

Returns the value of generic_read.

pub fn generic_read_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>

Returns the value of generic_read.

#Errors

If the returned value contains an invalid bit pattern for generic_read.

pub fn with_generic_read( self, new_val: <bool as Specifier>::InOut, ) -> MandatoryLabelAccessMask

Returns a copy of the bitfield with the value of generic_read set to the given value.

#Panics

If the given value is out of bounds for generic_read.

pub fn with_generic_read_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<MandatoryLabelAccessMask, OutOfBounds>

Returns a copy of the bitfield with the value of generic_read set to the given value.

#Errors

If the given value is out of bounds for generic_read.

pub fn set_generic_read(&mut self, new_val: <bool as Specifier>::InOut)

Sets the value of generic_read to the given value.

#Panics

If the given value is out of bounds for generic_read.

pub fn set_generic_read_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>

Sets the value of generic_read to the given value.

#Errors

If the given value is out of bounds for generic_read.