pub struct QueryDirectoryFlags { /* private fields */ }Implementations
Sourceimpl QueryDirectoryFlags
impl QueryDirectoryFlags
Sourcepub const fn new() -> QueryDirectoryFlags
pub const fn new() -> QueryDirectoryFlags
Returns an instance with zero initialized data.
Sourceimpl QueryDirectoryFlags
impl QueryDirectoryFlags
Sourcepub const fn into_bytes(self) -> [u8; 1]
pub const fn into_bytes(self) -> [u8; 1]
Sourcepub const fn from_bytes(bytes: [u8; 1]) -> QueryDirectoryFlags
pub const fn from_bytes(bytes: [u8; 1]) -> QueryDirectoryFlags
Converts the given bytes directly into the bitfield struct.
Sourceimpl QueryDirectoryFlags
impl QueryDirectoryFlags
Sourcepub fn restart_scans(&self) -> <bool as Specifier>::InOut
pub fn restart_scans(&self) -> <bool as Specifier>::InOut
Returns the value of restart_scans.
Sourcepub fn restart_scans_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn restart_scans_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of restart_scans.
#Errors
If the returned value contains an invalid bit pattern for restart_scans.
Sourcepub fn with_restart_scans(
self,
new_val: <bool as Specifier>::InOut,
) -> QueryDirectoryFlags
pub fn with_restart_scans( self, new_val: <bool as Specifier>::InOut, ) -> QueryDirectoryFlags
Returns a copy of the bitfield with the value of restart_scans set to the given value.
#Panics
If the given value is out of bounds for restart_scans.
Sourcepub fn with_restart_scans_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<QueryDirectoryFlags, OutOfBounds>
pub fn with_restart_scans_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<QueryDirectoryFlags, OutOfBounds>
Returns a copy of the bitfield with the value of restart_scans set to the given value.
#Errors
If the given value is out of bounds for restart_scans.
Sourcepub fn set_restart_scans(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_restart_scans(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of restart_scans to the given value.
#Panics
If the given value is out of bounds for restart_scans.
Sourcepub fn set_restart_scans_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_restart_scans_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of restart_scans to the given value.
#Errors
If the given value is out of bounds for restart_scans.
Sourcepub fn return_single_entry(&self) -> <bool as Specifier>::InOut
pub fn return_single_entry(&self) -> <bool as Specifier>::InOut
Returns the value of return_single_entry.
Sourcepub fn return_single_entry_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn return_single_entry_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of return_single_entry.
#Errors
If the returned value contains an invalid bit pattern for return_single_entry.
Sourcepub fn with_return_single_entry(
self,
new_val: <bool as Specifier>::InOut,
) -> QueryDirectoryFlags
pub fn with_return_single_entry( self, new_val: <bool as Specifier>::InOut, ) -> QueryDirectoryFlags
Returns a copy of the bitfield with the value of return_single_entry set to the given value.
#Panics
If the given value is out of bounds for return_single_entry.
Sourcepub fn with_return_single_entry_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<QueryDirectoryFlags, OutOfBounds>
pub fn with_return_single_entry_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<QueryDirectoryFlags, OutOfBounds>
Returns a copy of the bitfield with the value of return_single_entry set to the given value.
#Errors
If the given value is out of bounds for return_single_entry.
Sourcepub fn set_return_single_entry(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_return_single_entry(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of return_single_entry to the given value.
#Panics
If the given value is out of bounds for return_single_entry.
Sourcepub fn set_return_single_entry_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_return_single_entry_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of return_single_entry to the given value.
#Errors
If the given value is out of bounds for return_single_entry.
Sourcepub fn index_specified(&self) -> <bool as Specifier>::InOut
pub fn index_specified(&self) -> <bool as Specifier>::InOut
Returns the value of index_specified.
Sourcepub fn index_specified_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn index_specified_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of index_specified.
#Errors
If the returned value contains an invalid bit pattern for index_specified.
Sourcepub fn with_index_specified(
self,
new_val: <bool as Specifier>::InOut,
) -> QueryDirectoryFlags
pub fn with_index_specified( self, new_val: <bool as Specifier>::InOut, ) -> QueryDirectoryFlags
Returns a copy of the bitfield with the value of index_specified set to the given value.
#Panics
If the given value is out of bounds for index_specified.
Sourcepub fn with_index_specified_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<QueryDirectoryFlags, OutOfBounds>
pub fn with_index_specified_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<QueryDirectoryFlags, OutOfBounds>
Returns a copy of the bitfield with the value of index_specified set to the given value.
#Errors
If the given value is out of bounds for index_specified.
Sourcepub fn set_index_specified(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_index_specified(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of index_specified to the given value.
#Panics
If the given value is out of bounds for index_specified.
Sourcepub fn set_index_specified_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_index_specified_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of index_specified to the given value.
#Errors
If the given value is out of bounds for index_specified.
Sourcepub fn reopen_or_err(
&self,
) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
pub fn reopen_or_err( &self, ) -> Result<<bool as Specifier>::InOut, InvalidBitPattern<<bool as Specifier>::Bytes>>
Returns the value of reopen.
#Errors
If the returned value contains an invalid bit pattern for reopen.
Sourcepub fn with_reopen(
self,
new_val: <bool as Specifier>::InOut,
) -> QueryDirectoryFlags
pub fn with_reopen( self, new_val: <bool as Specifier>::InOut, ) -> QueryDirectoryFlags
Returns a copy of the bitfield with the value of reopen set to the given value.
#Panics
If the given value is out of bounds for reopen.
Sourcepub fn with_reopen_checked(
self,
new_val: <bool as Specifier>::InOut,
) -> Result<QueryDirectoryFlags, OutOfBounds>
pub fn with_reopen_checked( self, new_val: <bool as Specifier>::InOut, ) -> Result<QueryDirectoryFlags, OutOfBounds>
Returns a copy of the bitfield with the value of reopen set to the given value.
#Errors
If the given value is out of bounds for reopen.
Sourcepub fn set_reopen(&mut self, new_val: <bool as Specifier>::InOut)
pub fn set_reopen(&mut self, new_val: <bool as Specifier>::InOut)
Sets the value of reopen to the given value.
#Panics
If the given value is out of bounds for reopen.
Sourcepub fn set_reopen_checked(
&mut self,
new_val: <bool as Specifier>::InOut,
) -> Result<(), OutOfBounds>
pub fn set_reopen_checked( &mut self, new_val: <bool as Specifier>::InOut, ) -> Result<(), OutOfBounds>
Sets the value of reopen to the given value.
#Errors
If the given value is out of bounds for reopen.