QueryInfoResponseData

Struct QueryInfoResponseData 

pub struct QueryInfoResponseData { /* private fields */ }
A helper structure containing raw response data that can be parsed into specific information types.

Call QueryInfoResponseData::parse to convert to the appropriate data format based on the info type from the request.

Implementations