pub trait WriteAtChannel {
// Required method
fn write_at_channel(
&self,
buf: &[u8],
offset: u64,
channel: Option<u32>,
) -> impl Future<Output = Result<usize>> + Send;
}Expand description
This trait describes an object that can perform write operations at a specific offset, optionally using a specific channel ID.
It has a single method, WriteAtChannel::write_at_channel, which takes a buffer,
an offset, and an optional channel ID, and returns the number of bytes written.
Every structure that implements this trait, also implements the WriteAt trait, being
a subset of it. The WriteAt::write_at method is equivalent to calling
WriteAtChannel::write_at_channel with channel set to None.
Required Methods
fn write_at_channel( &self, buf: &[u8], offset: u64, channel: Option<u32>, ) -> impl Future<Output = Result<usize>> + Send
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.